#

##

##

##

    	ISO

    	Write an ISO to a drive

    		# write_ISO_to_drive.py

    	Extract the contents of an ISO

    		https://superuser.com/questions/17309/how-do-you-extract-install-from-an-iso-file

    		mount -o loop -t iso9660 file.iso /mnt/test

    	Compress a directory to an ISO

    		Ubuntu, GUID Partition Table:
    			Parition 1:
    				Type: EFI System:
    				Contents: FAT (32-bit version)
    				Device: /dev/sdd1

    			Partition 2:
    				Type: Linux Filesystem
    				Contents: Ext4
    				Device: /dev/sdd2

    		https://unix.stackexchange.com/questions/90793/create-iso-image-from-folder-via-terminal-commands

    		genisoimage -o output_image.iso directory_name

    		https://www.baeldung.com/linux/convert-bootable-usb-to-iso